summaryrefslogtreecommitdiffstats
path: root/net/socket/ssl_client_socket_openssl.h
diff options
context:
space:
mode:
Diffstat (limited to 'net/socket/ssl_client_socket_openssl.h')
-rw-r--r--net/socket/ssl_client_socket_openssl.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/net/socket/ssl_client_socket_openssl.h b/net/socket/ssl_client_socket_openssl.h
index 3d2194b..453be8f 100644
--- a/net/socket/ssl_client_socket_openssl.h
+++ b/net/socket/ssl_client_socket_openssl.h
@@ -106,10 +106,6 @@ class SSLClientSocketOpenSSL : public SSLClientSocket {
friend class SSLClientSocket;
friend class SSLContext;
- // Callback that is run by OpenSSL to obtain information about the
- // state of the SSL handshake.
- static void InfoCallback(const SSL* ssl, int result, int unused);
-
int Init();
void DoReadCallback(int result);
void DoWriteCallback(int result);
@@ -172,6 +168,10 @@ class SSLClientSocketOpenSSL : public SSLClientSocket {
const char *argp, int argi, long argl,
long retvalue);
+ // Callback that is used to obtain information about the state of the SSL
+ // handshake.
+ static void InfoCallback(const SSL* ssl, int type, int val);
+
void CheckIfHandshakeFinished();
bool transport_send_busy_;
@@ -211,11 +211,11 @@ class SSLClientSocketOpenSSL : public SSLClientSocket {
// error writing to the transport socket. A value of OK indicates no error.
int transport_write_error_;
// Set when handshake finishes.
scoped_ptr<PeerCertificateChain> server_cert_chain_;
scoped_refptr<X509Certificate> server_cert_;
CertVerifyResult server_cert_verify_result_;
- bool completed_handshake_;
+ bool completed_connect_;
// Set when Read() or Write() successfully reads or writes data to or from the
// network.
@@ -275,9 +275,9 @@ class SSLClientSocketOpenSSL : public SSLClientSocket {
// True if channel ID extension was negotiated.
bool channel_id_xtn_negotiated_;
// True if InfoCallback has been run with result = SSL_CB_HANDSHAKE_DONE.
- bool ran_handshake_finished_callback_;
+ bool handshake_succeeded_;
// True if MarkSSLSessionAsGood has been called for this socket's
- // connection's SSL session.
+ // SSL session.
bool marked_session_as_good_;
// The request handle for |channel_id_service_|.
ChannelIDService::RequestHandle channel_id_request_handle_;
@@ -211,11 +211,11 @@ class SSLClientSocketOpenSSL : public SSLClientSocket {
// error writing to the transport socket. A value of OK indicates no error.
int transport_write_error_;
- // Set when handshake finishes.
+ // Set when Connect finishes.
scoped_ptr<PeerCertificateChain> server_cert_chain_;
scoped_refptr<X509Certificate> server_cert_;